@@ -3,6 +3,7 @@ from precipy.identifiers import FileType
 from precipy.identifiers import GeneratedFile
 from precipy.identifiers import hash_for_fn
 from precipy.identifiers import hash_for_supplemental_file
+from precipy.identifiers import metadata_filename
 import os
 import pickle
 import shutil
@@ -11,7 +12,6 @@ import time
 import inspect
 
 class AnalyticsFunction(object):
-    metadata_filename = "metadata.pkl"
     metadata_keys = ["function_name", "function_source", "function_output", "kwargs", "files", "function_elapsed_seconds"]
 
     def __init__(self, fn, kwargs, key=None, previous_functions=None, storages=None, cachePath=None, constants=None, logger=None):
@@ -68,8 +68,8 @@ class AnalyticsFunction(object):
 
     def setup_files(self):
         self.files = {}
-        if not self.metadata_filename in self.files:
-            self.files[self.metadata_filename] = GeneratedFile(self.metadata_filename, self.h,
+        if not metadata_filename in self.files:
+            self.files[metadata_filename] = GeneratedFile(metadata_filename, self.h,
                     FileType.METADATA, cache_filepath = self.metadata_cache_filepath())
 
     def cache_dir(self, h):
@@ -125,7 +125,7 @@ class AnalyticsFunction(object):
         self.logger.debug("  saving metadata to %s" % filepath)
         with open(filepath, 'wb') as f:
             pickle.dump(self.function_metadata(), f)
-        self.upload_to_storages(self.metadata_filename, filepath)
+        self.upload_to_storages(metadata_filename, filepath)
     
     def read_metadata(self):
         with open(self.metadata_cache_filepath(), 'rb') as f:
