@@ -5,7 +5,7 @@ import os
 def do_markdown(input_filepath, output_filepath, output_ext, filter_args):
     with open(input_filepath, 'r') as i_f:
         with open(output_filepath, 'w') as o_f:
-            html = markdown.markdown(i_f.read())
+            html = markdown.markdown(i_f.read(), **filter_args)
             o_f.write(html)
     assert os.path.exists(output_filepath)
 
